@@ -2,7 +2,7 @@
 
 ;; Copyright (C) 2005, 2006, 2007, 2008, 2009  Free Software Foundation, Inc.
 
-;; Author: Yoni Rabkin <yonirabkin@member.fsf.org>
+;; Author: Yoni Rabkin <yrk@gnu.org>
 
 ;; This file is part of EMMS.
 
@@ -112,7 +112,7 @@ This is true for every invocation of `emms-playlist-mode-go'."
 ;;; Keys
 ;;; --------------------------------------------------------
 
-(defconst emms-playlist-mode-map
+(defvar emms-playlist-mode-map
   (let ((map (make-sparse-keymap)))
     (set-keymap-parent map text-mode-map)
     (define-key map (kbd "C-x C-s") 'emms-playlist-save)
